@@ -7,14 +7,16 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Tester 4.008;
+package Config::Model::Tester 4.009;
 # ABSTRACT: Test framework for Config::Model
 
 use warnings;
 use strict;
 use locale;
 use utf8;
-use 5.12.0;
+use v5.20;
+
+use feature qw/postderef signatures/;
 
 use Test::More;
 use Log::Log4perl 1.11 qw(:easy :levels);
@@ -39,6 +41,7 @@ eval {
     require Config::Model::BackendMgr;
 } ;
 
+## no critic (Modules::ProhibitAutomaticExportation)
 use vars qw/@ISA @EXPORT/;
 
 require Exporter;
@@ -164,6 +167,7 @@ sub write_config_file {
         $file .= $t->{config_file} ;
         $wr_dir->child($file)->parent->mkpath({mode => oct(755)} ) ;
     }
+    return;
 }
 
 sub check_load_warnings {
@@ -183,6 +187,7 @@ sub check_load_warnings {
         warnings_like { $root->init; } $t->{load_warnings},
             "Read configuration and created instance with init() method with warning check ";
     }
+    return;
 }
 
 sub run_update {
@@ -228,6 +233,7 @@ sub run_update {
     else {
         ok(1,"dumped configuration");
     }
+    return;
 }
 
 sub load_instructions {
@@ -236,6 +242,7 @@ sub load_instructions {
     print "Loading $steps\n" if $trace ;
     $root->load( $steps );
     ok( 1, "load called" );
+    return;
 }
 
 sub apply_fix {
@@ -243,6 +250,7 @@ sub apply_fix {
     local $Config::Model::Value::nowarning = 1;
     $inst->apply_fixes;
     ok( 1, "apply_fixes called" );
+    return;
 }
 
 sub dump_tree {
@@ -303,6 +311,7 @@ sub check_data {
         my $v          = shift @checks;
         check_one_item($label, $root,$path, $v);
     }
+    return;
 }
 
 sub check_one_item {
@@ -327,6 +336,7 @@ sub check_one_item {
             }
         }
     }
+    return;
 }
 
 sub check_annotation {
@@ -337,18 +347,21 @@ sub check_annotation {
         my $note = $annot_check->{$path};
         is( $root->grab($path)->annotation, $note, "check $path annotation" );
     }
+    return;
 }
 
 sub has_key {
     my ($root, $c, $nw) = @_;
 
     _test_key($root, $c, $nw, 0);
+    return;
 }
 
 sub has_not_key {
     my ($root, $c, $nw) = @_;
 
     _test_key($root, $c, $nw, 1);
+    return;
 }
 
 sub _test_key {
@@ -383,6 +396,7 @@ sub _test_key {
             }
         }
     }
+    return;
 }
 
 sub write_data_back {
@@ -390,6 +404,7 @@ sub write_data_back {
     local $Config::Model::Value::nowarning = $t->{no_warnings} || 0;
     $inst->write_back( force => 1 );
     ok( 1, "$test_group write back done" );
+    return;
 }
 
 sub check_file_mode {
@@ -411,6 +426,7 @@ sub check_file_mode {
             }
         }
     }
+    return;
 }
 
 sub check_file_content {
@@ -448,6 +464,7 @@ sub check_file_content {
             }
         }
     }
+    return;
 }
 
 sub check_added_or_removed_files {
@@ -461,6 +478,7 @@ sub check_added_or_removed_files {
     my @new_file_list = list_test_files($destination_dir) ;
     $t->{file_check_sub}->( \@file_list ) if defined $t->{file_check_sub};
     eq_or_diff( \@new_file_list, [ sort @file_list ], "check added or removed files" );
+    return;
 }
 
 sub create_second_instance {
@@ -501,6 +519,7 @@ sub create_test_class {
         my @parms = ref($c) eq 'HASH' ? %$c : @$c;
         $model->create_config_class(@parms);
     }
+    return;
 }
 
 our ($model, $conf_file_name, $conf_dir, $model_to_test, $app_to_test, $home_for_test, @tests, $skip);
@@ -686,11 +705,13 @@ sub run_model_test {
     }
     note("End of $test_group test");
 
+    return;
 }
 
 sub translate_test_data {
     my $t = shift;
     map {$t->{full_dump}{$_} = delete $t->{$_} if $t->{$_}; } qw/dump_warnings dump_errors/;
+    return;
 }
 
 sub create_model_object {
@@ -704,14 +725,14 @@ sub create_model_object {
     return $new_model;
 }
 
-sub run_tests {
+sub run_tests (@args) {
     my ( $test_only_app, $do, $trace, $wr_root );
     my $model;
     my $test_logs;
-    if (@_) {
+    if (@args) {
         my $arg;
         note ("Calling run_tests with argument is deprecated");
-        ( $arg, $test_only_app, $do ) = @_;
+        ( $arg, $test_only_app, $do ) = @args;
 
         my $log = 0;
 
@@ -757,7 +778,9 @@ sub run_tests {
 
     done_testing;
 
+    return;
 }
+
 1;
 
 __END__
@@ -772,7 +795,7 @@ Config::Model::Tester - Test framework for Config::Model
 
 =head1 VERSION
 
-version 4.008
+version 4.009
 
 =head1 SYNOPSIS
 
@@ -1039,7 +1062,7 @@ test must be specified in a global test parameter:
 
 =head2 Test specification with arbitrary file names
 
-In some models, like C<Multistrap>, the config file is chosen by the
+In some models, like late C<Multistrap>, the config file is chosen by the
 user. In this case, the file name must be specified for each tests
 case:
 
@@ -1051,8 +1074,6 @@ case:
     }]
  };
 
-See the actual L<multistrap test|https://github.com/dod38fr/config-model/blob/master/t/model_tests.d/multistrap-test-conf.pl>.
-
 =head2 Backend argument
 
 Some application like systemd requires a backend argument specified by
@@ -1488,15 +1509,8 @@ Dpkg packages are constructed from several files. These files are handled like
 configuration files by L<Config::Model::Dpkg|https://salsa.debian.org/perl-team/modules/packages/libconfig-model-dpkg-perl>. The
 L<test layout|https://salsa.debian.org/perl-team/modules/packages/libconfig-model-dpkg-perl/-/tree/master/t/model_tests.d>
 features test with multiple file in
-L<dpkg-examples|https://salsa.debian.org/perl-team/modules/packages/libconfig-model-dpkg-perl/-/tree/master/t/model_tests.d/dpkg-examples>.
-The test is specified in L<https://salsa.debian.org/perl-team/modules/packages/libconfig-model-dpkg-perl/-/blob/master/t/model_tests.d/dpkg-test-conf.pl>
-
-=item *
-
-L<multistrap-test-conf.pl|https://github.com/dod38fr/config-model/blob/master/t/model_tests.d/multistrap-test-conf.pl>
-and L<multistrap-examples|https://github.com/dod38fr/config-model/tree/master/t/model_tests.d/multistrap-examples>
-specify a test where the configuration file name is not imposed by the
-application. The file name must then be set in the test specification.
+L<dpkg-examples|https://deb.li/F8cx>.
+The test is specified in L<https://deb.li/3fx4E>.
 
 =item *
 
